@@ -9,7 +9,7 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.CodeGuruReviewer 1.22.0\nVersion:         1.22.0.post1\nBuilder"
+        "Type annotations for boto3.CodeGuruReviewer 1.22.4\nVersion:         1.22.4\nBuilder"
         " version: 7.5.9\nDocs:           "
         " https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer//\nBoto3 docs:   "
         "   https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codeguru-reviewer.html#CodeGuruReviewer\nOther"
@@ -22,7 +22,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.22.0.post1")
+    print("1.22.4")
 
 
 def main() -> None:
