@@ -22,6 +22,7 @@ else:
 __all__ = (
     "AnalysisTypeType",
     "CodeReviewCompletedWaiterName",
+    "ConfigFileStateType",
     "EncryptionOptionType",
     "JobStateType",
     "ListRepositoryAssociationsPaginatorName",
@@ -44,6 +45,7 @@ __all__ = (
 
 AnalysisTypeType = Literal["CodeQuality", "Security"]
 CodeReviewCompletedWaiterName = Literal["code_review_completed"]
+ConfigFileStateType = Literal["Absent", "Present", "PresentWithErrors"]
 EncryptionOptionType = Literal["AWS_OWNED_CMK", "CUSTOMER_MANAGED_CMK"]
 JobStateType = Literal["Completed", "Deleting", "Failed", "Pending"]
 ListRepositoryAssociationsPaginatorName = Literal["list_repository_associations"]
@@ -109,6 +111,7 @@ ServiceName = Literal[
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-media-pipelines",
     "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
@@ -224,6 +227,7 @@ ServiceName = Literal[
     "iottwinmaker",
     "iotwireless",
     "ivs",
+    "ivschat",
     "kafka",
     "kafkaconnect",
     "kendra",
